[Checkins] SVN: zc.buildout/branches/use_distribute/ - switch back to using setuptools package name

Chris Withers chris at simplistix.co.uk
Tue Sep 8 06:46:19 EDT 2009


Log message for revision 103641:
  - switch back to using setuptools package name
  - correct tests/docs to use "distribute" instead of "setuptools" where needed.

Changed:
  U   zc.buildout/branches/use_distribute/setup.py
  U   zc.buildout/branches/use_distribute/src/zc/buildout/buildout.txt
  U   zc.buildout/branches/use_distribute/src/zc/buildout/easy_install.txt
  U   zc.buildout/branches/use_distribute/src/zc/buildout/repeatable.txt
  U   zc.buildout/branches/use_distribute/src/zc/buildout/tests.py
  U   zc.buildout/branches/use_distribute/src/zc/buildout/unzip.txt
  U   zc.buildout/branches/use_distribute/src/zc/buildout/update.txt
  U   zc.buildout/branches/use_distribute/zc.recipe.egg_/src/zc/recipe/egg/README.txt
  U   zc.buildout/branches/use_distribute/zc.recipe.egg_/src/zc/recipe/egg/api.txt

-=-
Modified: zc.buildout/branches/use_distribute/setup.py
===================================================================
--- zc.buildout/branches/use_distribute/setup.py	2009-09-08 10:36:02 UTC (rev 103640)
+++ zc.buildout/branches/use_distribute/setup.py	2009-09-08 10:46:18 UTC (rev 103641)
@@ -15,7 +15,7 @@
 version = "1.4.0-distribute-dev"
 
 import os
-from distribute import setup, find_packages
+from setuptools import setup, find_packages
 
 def read(*rnames):
     return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

Modified: zc.buildout/branches/use_distribute/src/zc/buildout/buildout.txt
===================================================================
--- zc.buildout/branches/use_distribute/src/zc/buildout/buildout.txt	2009-09-08 10:36:02 UTC (rev 103640)
+++ zc.buildout/branches/use_distribute/src/zc/buildout/buildout.txt	2009-09-08 10:46:18 UTC (rev 103641)
@@ -18,7 +18,7 @@
    script installed in a Python scripts area.
 
 2. Use the buildout bootstrap script to create a buildout that
-   includes both the setuptools and zc.buildout eggs.  This allows you
+   includes both the distribute and zc.buildout eggs.  This allows you
    to use the buildout software without modifying a Python install.
    The buildout script is installed into your buildout local scripts
    area.
@@ -32,7 +32,7 @@
 directories, buildout configuration files, and a copy of the buildout
 bootstrap script.  To work on the project, one would check out the
 project from the repository and run the bootstrap script which
-installs setuptools and zc.buildout into the checkout as well as any
+installs distribute and zc.buildout into the checkout as well as any
 parts defined.
 
 We have a sample buildout that we created using the bootstrap command
@@ -53,7 +53,7 @@
     -  buildout
 
     >>> ls(sample_buildout, 'eggs')
-    -  setuptools-0.6-py2.4.egg
+    -  distribute-0.6-py2.4.egg
     -  zc.buildout-1.0-py2.4.egg
 
 The develop-eggs and parts directories are initially empty:
@@ -228,7 +228,7 @@
 give entry points names within the group.
 
 We also need a README.txt for our recipes to avoid an annoying warning
-from distutils, on which setuptools and zc.buildout are based:
+from distutils, on which distribute and zc.buildout are based:
 
     >>> write(sample_buildout, 'recipes', 'README.txt', " ")
 
@@ -2109,10 +2109,10 @@
     ... """)
 
     >>> print system(buildout+' -vv'),
-    Installing 'zc.buildout', 'setuptools'.
+    Installing 'zc.buildout', 'distribute'.
     We have a develop egg: zc.buildout 1.0.0.
-    We have the best distribution that satisfies 'setuptools'.
-    Picked: setuptools = 0.6
+    We have the best distribution that satisfies 'distribute'.
+    Picked: distribute = 0.6
     <BLANKLINE>
     Configuration data:
     [buildout]
@@ -2198,7 +2198,7 @@
 ----------------------------------------
 
 If zc.buildout is installed, you can use it to create a new buildout
-with it's own local copies of zc.buildout and setuptools and with
+with it's own local copies of zc.buildout and distribute and with
 local buildout scripts.
 
     >>> sample_bootstrapped = tmpdir('sample-bootstrapped')
@@ -2227,13 +2227,13 @@
 
     >>> _ = (ls(sample_bootstrapped, 'eggs'),
     ...      ls(sample_bootstrapped, 'develop-eggs'))
-    -  setuptools-0.6-py2.3.egg
+    -  distribute-0.6-py2.3.egg
     -  zc.buildout-1.0-py2.3.egg
 
 (We list both the eggs and develop-eggs directories because the
-buildout or setuptools egg could be installed in the develop-eggs
+buildout or distribute egg could be installed in the develop-eggs
 directory if the original buildout had develop eggs for either
-buildout or setuptools.)
+buildout or distribute.)
 
 Note that the buildout script was installed but not run.  To run
 the buildout, we'd have to run the installed buildout script.
@@ -2360,7 +2360,7 @@
 Dependency links
 ----------------
 
-By default buildout will obey the setuptools dependency_links metadata
+By default buildout will obey the distribute dependency_links metadata
 when it looks for dependencies. This behavior can be controlled with
 the use-dependency-links buildout option::
 

Modified: zc.buildout/branches/use_distribute/src/zc/buildout/easy_install.txt
===================================================================
--- zc.buildout/branches/use_distribute/src/zc/buildout/easy_install.txt	2009-09-08 10:36:02 UTC (rev 103640)
+++ zc.buildout/branches/use_distribute/src/zc/buildout/easy_install.txt	2009-09-08 10:46:18 UTC (rev 103641)
@@ -28,7 +28,7 @@
 or more packages and their dependencies.  The install function takes 2
 positional arguments:
 
-- An iterable of setuptools requirement strings for the distributions
+- An iterable of distribute requirement strings for the distributions
   to be installed, and
 
 - A destination directory to install to and to satisfy requirements
@@ -402,7 +402,7 @@
 Dependency links
 ----------------
 
-Setuptools allows metadata that describes where to search for package
+Distribute allows metadata that describes where to search for package
 dependencies. This option is called dependency_links. Buildout has its
 own notion of where to look for dependencies, but it also uses the
 setup tools dependency_links information if it's available.
@@ -522,7 +522,7 @@
 -----------------
 
 The easy_install module provides support for creating scripts from
-eggs.  It provides a function similar to setuptools except that it
+eggs.  It provides a function similar to distribute except that it
 provides facilities for baking a script's path into the script.  This
 has two advantages:
 
@@ -549,7 +549,7 @@
 the four arguments we passed were:
 
 1. A sequence of distribution requirements.  These are of the same
-   form as setuptools requirements.  Here we passed a single
+   form as distribute requirements.  Here we passed a single
    requirement, for the version 0.1 demo distribution.
 
 2. A working set,
@@ -633,7 +633,7 @@
 
 Passing entry-point information directly is handy when using eggs (or
 distributions) that don't declare their entry points, such as
-distributions that aren't based on setuptools.
+distributions that aren't based on distribute.
 
 The interpreter keyword argument can be used to generate a script that can
 be used to invoke the Python interactive interpreter with the path set
@@ -1177,7 +1177,7 @@
     GET 200 /demo-0.2-py2.4.egg
     GET 404 /index/demoneeded/
     GET 200 /demoneeded-1.1.zip
-    GET 404 /index/setuptools/
+    GET 404 /index/distribute/
 
     >>> zc.buildout.easy_install.build(
     ...   'extdemo', dest,
@@ -1220,7 +1220,7 @@
     GET 404 /index/demo/
     GET 200 /index/
     GET 404 /index/demoneeded/
-    GET 404 /index/setuptools/
+    GET 404 /index/distribute/
 
     >>> zc.buildout.easy_install.build(
     ...   'extdemo', dest,

Modified: zc.buildout/branches/use_distribute/src/zc/buildout/repeatable.txt
===================================================================
--- zc.buildout/branches/use_distribute/src/zc/buildout/repeatable.txt	2009-09-08 10:36:02 UTC (rev 103640)
+++ zc.buildout/branches/use_distribute/src/zc/buildout/repeatable.txt	2009-09-08 10:46:18 UTC (rev 103641)
@@ -124,10 +124,10 @@
 specifying a versions section:
 
     >>> print system(buildout+' buildout:versions= -v'), # doctest: +ELLIPSIS
-    Installing 'zc.buildout', 'setuptools'.
+    Installing 'zc.buildout', 'distribute'.
     We have a develop egg: zc.buildout 1.0.0.
-    We have the best distribution that satisfies 'setuptools'.
-    Picked: setuptools = 0.6
+    We have the best distribution that satisfies 'distribute'.
+    Picked: distribute = 0.6
     Installing 'spam'.
     We have the best distribution that satisfies 'spam'.
     Picked: spam = 2.
@@ -146,10 +146,10 @@
 If we run the buildout with the versions section:
 
     >>> print system(buildout+' -v'), # doctest: +ELLIPSIS
-    Installing 'zc.buildout', 'setuptools'.
+    Installing 'zc.buildout', 'distribute'.
     We have a develop egg: zc.buildout 1.0.0.
-    We have the best distribution that satisfies 'setuptools'.
-    Picked: setuptools = 0.6
+    We have the best distribution that satisfies 'distribute'.
+    Picked: distribute = 0.6
     Installing 'spam'.
     We have the distribution that satisfies 'spam==1'.
     Uninstalling foo.
@@ -157,7 +157,7 @@
     recipe v1
 
 We won't get output for the spam distribution, which we didn't pick,
-but we will get output for setuptools, which we didn't specify
+but we will get output for distribute, which we didn't specify
 versions for.
 
 You can request buildout to generate an error if it picks any

Modified: zc.buildout/branches/use_distribute/src/zc/buildout/tests.py
===================================================================
--- zc.buildout/branches/use_distribute/src/zc/buildout/unzip.txt	2009-09-08 10:36:02 UTC (rev 103640)
+++ zc.buildout/branches/use_distribute/src/zc/buildout/unzip.txt	2009-09-08 10:46:18 UTC (rev 103641)
@@ -18,11 +18,11 @@
     >>> ls('eggs')
     -  demo-0.4c1-py2.4.egg
     -  demoneeded-1.2c1-py2.4.egg
-    d  setuptools-0.6c8-py2.4.egg
+    d  distribute-0.6c8-py2.4.egg
     -  zc.buildout.egg-link
 
 This follows the
-policy followed by setuptools itself.  Experience shows this policy
+policy followed by distribute itself.  Experience shows this policy
 to to be inconvenient.  Zipped eggs make debugging more difficult and
 often import more slowly.
 
@@ -51,5 +51,5 @@
     >>> ls('eggs')
     d  demo-0.4c1-py2.4.egg
     d  demoneeded-1.2c1-py2.4.egg
-    d  setuptools-0.6c8-py2.4.egg
+    d  distribute-0.6c8-py2.4.egg
     -  zc.buildout.egg-link

Modified: zc.buildout/branches/use_distribute/src/zc/buildout/update.txt
===================================================================
--- zc.buildout/branches/use_distribute/src/zc/buildout/update.txt	2009-09-08 10:36:02 UTC (rev 103640)
+++ zc.buildout/branches/use_distribute/src/zc/buildout/update.txt	2009-09-08 10:46:18 UTC (rev 103641)
@@ -2,13 +2,13 @@
 ==========================
 
 When a buildout is run, one of the first steps performed is to check
-for updates to either zc.buildout or setuptools.  To demonstrate this,
-we've creates some "new releases" of buildout and setuptools in a
+for updates to either zc.buildout or distribute.  To demonstrate this,
+we've creates some "new releases" of buildout and distribute in a
 new_releases folder:
 
     >>> ls(new_releases)
-    d  setuptools
-    -  setuptools-99.99-py2.4.egg
+    d  distribute
+    -  distribute-99.99-py2.4.egg
     d  zc.buildout
     -  zc.buildout-99.99-py2.4.egg
 
@@ -26,7 +26,7 @@
     ... recipe = showversions
     ... """ % dict(new_releases=new_releases))
 
-We'll also include a recipe that echos the versions of setuptools and
+We'll also include a recipe that echos the versions of distribute and
 zc.buildout used:
 
     >>> mkdir(sample_buildout, 'showversions')
@@ -41,7 +41,7 @@
     ...         pass
     ...
     ...     def install(self):
-    ...         for project in 'zc.buildout', 'setuptools':
+    ...         for project in 'zc.buildout', 'distribute':
     ...             req = pkg_resources.Requirement.parse(project)
     ...             print project, pkg_resources.working_set.find(req).version
     ...         return ()
@@ -66,17 +66,17 @@
     >>> print system(buildout),
     Getting distribution for 'zc.buildout'.
     Got zc.buildout 99.99.
-    Getting distribution for 'setuptools'.
-    Got setuptools 99.99.
+    Getting distribution for 'distribute'.
+    Got distribute 99.99.
     Upgraded:
       zc.buildout version 99.99,
-      setuptools version 99.99;
+      distribute version 99.99;
     restarting.
     Generated script '/sample-buildout/bin/buildout'.
     Develop: '/sample-buildout/showversions'
     Installing show-versions.
     zc.buildout 99.99
-    setuptools 99.99
+    distribute 99.99
 
 Our buildout script has been updated to use the new eggs:
 
@@ -86,7 +86,7 @@
     import sys
     sys.path[0:0] = [
       '/sample-buildout/eggs/zc.buildout-99.99-py2.4.egg',
-      '/sample-buildout/eggs/setuptools-99.99-py2.4.egg',
+      '/sample-buildout/eggs/distribute-99.99-py2.4.egg',
       ]
     <BLANKLINE>
     import zc.buildout.buildout
@@ -95,7 +95,7 @@
         zc.buildout.buildout.main()
 
 Now, let's recreate the sample buildout. If we specify constraints on
-the versions of zc.buildout and setuptools to use, running the
+the versions of zc.buildout and distribute to use, running the
 buildout will install earlier versions of these packages:
 
     >>> write(sample_buildout, 'buildout.cfg',
@@ -106,7 +106,7 @@
     ... parts = show-versions
     ... develop = showversions
     ... zc.buildout-version = < 99
-    ... setuptools-version = < 99
+    ... distribute-version = < 99
     ... 
     ... [show-versions]
     ... recipe = showversions
@@ -117,13 +117,13 @@
     >>> print system(buildout),
     Upgraded:
       zc.buildout version 1.0.0,
-      setuptools version 0.6;
+      distribute version 0.6;
     restarting.
     Generated script '/sample-buildout/bin/buildout'.
     Develop: '/sample-buildout/showversions'
     Updating show-versions.
     zc.buildout 1.0.0
-    setuptools 0.6
+    distribute 0.6
 
 There are a number of cases, described below, in which the updates
 don't happen. 
@@ -146,7 +146,7 @@
     Develop: '/sample-buildout/showversions'
     Updating show-versions.
     zc.buildout 1.0.0
-    setuptools 0.6
+    distribute 0.6
 
 Or in non-newest mode:
 
@@ -154,7 +154,7 @@
     Develop: '/sample-buildout/showversions'
     Updating show-versions.
     zc.buildout 1.0.0
-    setuptools 0.6
+    distribute 0.6
 
 We also won't upgrade if the buildout script being run isn't in the
 buildouts bin directory.  To see this we'll create a new buildout
@@ -177,8 +177,8 @@
     Creating directory '/sample_buildout2/develop-eggs'.
     Getting distribution for 'zc.buildout'.
     Got zc.buildout 99.99.
-    Getting distribution for 'setuptools'.
-    Got setuptools 99.99.
+    Getting distribution for 'distribute'.
+    Got distribute 99.99.
     Not upgrading because not running a local buildout command.
 
     >>> ls('bin')

Modified: zc.buildout/branches/use_distribute/zc.recipe.egg_/src/zc/recipe/egg/README.txt
===================================================================
--- zc.buildout/branches/use_distribute/zc.recipe.egg_/src/zc/recipe/egg/README.txt	2009-09-08 10:36:02 UTC (rev 103640)
+++ zc.buildout/branches/use_distribute/zc.recipe.egg_/src/zc/recipe/egg/README.txt	2009-09-08 10:46:18 UTC (rev 103641)
@@ -5,7 +5,7 @@
 distutils distributions as eggs.  It takes a number of options:
 
 eggs
-    A list of eggs to install given as one or more setuptools
+    A list of eggs to install given as one or more distribute
     requirement strings.  Each string must be given on a separate
     line.
 
@@ -79,7 +79,7 @@
     >>> ls(sample_buildout, 'eggs')
     -  demo-0.2-py2.3.egg
     -  demoneeded-1.2c1-py2.3.egg
-    -  setuptools-0.6-py2.3.egg
+    -  distribute-0.6-py2.3.egg
     -  zc.buildout-1.0-py2.3.egg
 
 We see that we got an egg for demo that met the requirement, as well
@@ -135,7 +135,7 @@
 
    This option is useful when working with distributions that don't
    declare entry points, such as distributions not written to work
-   with setuptools. 
+   with distribute. 
 
    Examples can be seen in the section "Specifying entry points" below.
 
@@ -268,7 +268,7 @@
     >>> ls(sample_buildout, 'eggs')
     -  demo-0.2-py2.3.egg
     -  demoneeded-1.2c1-py2.3.egg
-    -  setuptools-0.6-py2.3.egg
+    -  distribute-0.6-py2.3.egg
     -  zc.buildout-1.0-py2.3.egg
 
 If we run the buildout on the default online and newest modes, 
@@ -286,7 +286,7 @@
     -  demo-0.2-py2.3.egg
     -  demo-0.4c1-py2.3.egg
     -  demoneeded-1.2c1-py2.3.egg
-    -  setuptools-0.6-py2.4.egg
+    -  distribute-0.6-py2.4.egg
     -  zc.buildout-1.0-py2.4.egg
 
 The script is updated too:

Modified: zc.buildout/branches/use_distribute/zc.recipe.egg_/src/zc/recipe/egg/api.txt
===================================================================
--- zc.buildout/branches/use_distribute/zc.recipe.egg_/src/zc/recipe/egg/api.txt	2009-09-08 10:36:02 UTC (rev 103640)
+++ zc.buildout/branches/use_distribute/zc.recipe.egg_/src/zc/recipe/egg/api.txt	2009-09-08 10:46:18 UTC (rev 103641)
@@ -103,7 +103,7 @@
     __buildout_installed__ = 
     __buildout_signature__ = sample-6aWMvV2EJ9Ijq+bR8ugArQ==
             zc.recipe.egg-cAsnudgkduAa/Fd+WJIM6Q==
-            setuptools-0.6-py2.4.egg
+            distribute-0.6-py2.4.egg
             zc.buildout-+rYeCcmFuD1K/aB77XTj5A==
     _b = /sample-buildout/bin
     _d = /sample-buildout/develop-eggs



More information about the checkins mailing list
--- zc.buildout/branches/use_distribute/src/zc/buildout/tests.py	2009-09-08 10:36:02 UTC (rev 103640)
+++ zc.buildout/branches/use_distribute/src/zc/buildout/tests.py	2009-09-08 10:46:18 UTC (rev 103641)
@@ -28,9 +28,9 @@
     os_path_sep *= 2
 
 
-def develop_w_non_setuptools_setup_scripts():
+def develop_w_non_distribute_setup_scripts():
     """
-We should be able to deal with setup scripts that aren't setuptools based.
+We should be able to deal with setup scripts that aren't distribute based.
 
     >>> mkdir('foo')
     >>> write('foo', 'setup.py',
@@ -57,7 +57,7 @@
 
 def develop_verbose():
     """
-We should be able to deal with setup scripts that aren't setuptools based.
+We should be able to deal with setup scripts that aren't distribute based.
 
     >>> mkdir('foo')
     >>> write('foo', 'setup.py',
@@ -318,10 +318,10 @@
 If we use the verbose switch, we can see where requirements are comning from:
 
     >>> print system(buildout+' -v'), # doctest: +ELLIPSIS
-    Installing 'zc.buildout', 'setuptools'.
+    Installing 'zc.buildout', 'distribute'.
     We have a develop egg: zc.buildout 1.0.0
-    We have the best distribution that satisfies 'setuptools'.
-    Picked: setuptools = 0.6
+    We have the best distribution that satisfies 'distribute'.
+    Picked: distribute = 0.6
     Develop: '/sample-buildout/sampley'
     Develop: '/sample-buildout/samplez'
     Develop: '/sample-buildout/samplea'
@@ -557,7 +557,7 @@
     ... ''')
 
     >>> print system(buildout + ' foo:bar=1 -vv'), # doctest: +ELLIPSIS
-    Installing 'zc.buildout', 'setuptools'.
+    Installing 'zc.buildout', 'distribute'.
     ...
     [foo]
     bar = 1
@@ -726,14 +726,14 @@
     '''
 
 
-def add_setuptools_to_dependencies_when_namespace_packages():
+def add_distribute_to_dependencies_when_namespace_packages():
     '''
-Often, a package depends on setuptools soley by virtue of using
+Often, a package depends on distribute soley by virtue of using
 namespace packages. In this situation, package authors often forget to
-declare setuptools as a dependency. This is a mistake, but,
+declare distribute as a dependency. This is a mistake, but,
 unfortunately, a common one that we need to work around.  If an egg
-uses namespace packages and does not include setuptools as a depenency,
-we will still include setuptools in the working set.  If we see this for
+uses namespace packages and does not include distribute as a depenency,
+we will still include distribute in the working set.  If we see this for
 a devlop egg, we will also generate a warning.
 
     >>> mkdir('foo')
@@ -742,15 +742,15 @@
     >>> write('foo', 'src', 'stuff', '__init__.py',
     ... """__import__('pkg_resources').declare_namespace(__name__)
     ... """)
-    >>> mkdir('foo', 'src', 'stuff', 'foox')
-    >>> write('foo', 'src', 'stuff', 'foox', '__init__.py', '')
+    >>> mkdir('foo', 'src', 'stuff', 'afoox')
+    >>> write('foo', 'src', 'stuff', 'afoox', '__init__.py', '')
     >>> write('foo', 'setup.py',
     ... """
     ... from setuptools import setup
-    ... setup(name='foox',
+    ... setup(name='afoox',
     ...       namespace_packages = ['stuff'],
     ...       package_dir = {'': 'src'},
-    ...       packages = ['stuff', 'stuff.foox'],
+    ...       packages = ['stuff', 'stuff.afoox'],
     ...       )
     ... """)
     >>> write('foo', 'README.txt', '')
@@ -766,7 +766,7 @@
     Develop: '/sample-buildout/foo'
 
 Now, if we generate a working set using the egg link, we will get a warning
-and we will get setuptools included in the working set.
+and we will get distribute included in the working set.
 
     >>> import logging, zope.testing.loggingsupport
     >>> handler = zope.testing.loggingsupport.InstalledHandler(
@@ -775,22 +775,22 @@
 
     >>> [dist.project_name
     ...  for dist in zc.buildout.easy_install.working_set(
-    ...    ['foox'], sys.executable,
+    ...    ['afoox'], sys.executable,
     ...    [join(sample_buildout, 'eggs'),
     ...     join(sample_buildout, 'develop-eggs'),
     ...     ])]
-    ['foox', 'setuptools']
+    ['afoox', 'distribute']
 
     >>> print handler
     zc.buildout.easy_install WARNING
-      Develop distribution: foox 0.0.0
-    uses namespace packages but the distribution does not require setuptools.
+      Develop distribution: afoox 0.0.0
+    uses namespace packages but the distribution does not require distribute.
 
     >>> handler.clear()
 
 On the other hand, if we have a regular egg, rather than a develop egg:
 
-    >>> os.remove(join('develop-eggs', 'foox.egg-link'))
+    >>> os.remove(join('develop-eggs', 'afoox.egg-link'))
 
     >>> _ = system(join('bin', 'buildout') + ' setup foo bdist_egg -d'
     ...            + join(sample_buildout, 'eggs'))
@@ -799,18 +799,18 @@
     -  zc.recipe.egg.egg-link
 
     >>> ls('eggs') # doctest: +ELLIPSIS
-    -  foox-0.0.0-py2.4.egg
+    -  afoox-0.0.0-py2.4.egg
     ...
 
-We do not get a warning, but we do get setuptools included in the working set:
+We do not get a warning, but we do get distribute included in the working set:
 
     >>> [dist.project_name
     ...  for dist in zc.buildout.easy_install.working_set(
-    ...    ['foox'], sys.executable,
+    ...    ['afoox'], sys.executable,
     ...    [join(sample_buildout, 'eggs'),
     ...     join(sample_buildout, 'develop-eggs'),
     ...     ])]
-    ['foox', 'setuptools']
+    ['afoox', 'distribute']
 
     >>> print handler,
 
@@ -822,7 +822,7 @@
     >>> write('bar', 'setup.py',
     ... """
     ... from setuptools import setup
-    ... setup(name='bar', install_requires = ['foox'])
+    ... setup(name='bar', install_requires = ['afoox'])
     ... """)
     >>> write('bar', 'README.txt', '')
 
@@ -843,12 +843,12 @@
     ...    [join(sample_buildout, 'eggs'),
     ...     join(sample_buildout, 'develop-eggs'),
     ...     ])]
-    ['bar', 'foox', 'setuptools']
+    ['bar', 'afoox', 'distribute']
 
     >>> print handler,
     zc.buildout.easy_install WARNING
-      Develop distribution: foox 0.0.0
-    uses namespace packages but the distribution does not require setuptools.
+      Develop distribution: afoox 0.0.0
+    uses namespace packages but the distribution does not require distribute.
 
 
     >>> logging.getLogger('zc.buildout.easy_install').propagate = True
@@ -1892,7 +1892,7 @@
 def bug_61890_file_urls_dont_seem_to_work_in_find_dash_links():
     """
 
     This bug arises from the fact that setuptools is overly restrictive
     about file urls, requiring that file urls pointing at directories
     must end in a slash.
 
@@ -1976,10 +1976,10 @@
     However, if we run in verbose mode, we can see why packages were included:
 
     >>> print system(buildout+' -v'), # doctest: +ELLIPSIS
-    Installing 'zc.buildout', 'setuptools'.
+    Installing 'zc.buildout', 'distribute'.
     We have a develop egg: zc.buildout 1.0.0
-    We have the best distribution that satisfies 'setuptools'.
-    Picked: setuptools = 0.6
+    We have the best distribution that satisfies 'distribute'.
+    Picked: distribute = 0.6
     Develop: '/sample-buildout/pack0'
     Develop: '/sample-buildout/pack1'
     Develop: '/sample-buildout/pack2'
@@ -2267,7 +2267,7 @@
     ... ''' % globals())
 
     >>> print system(buildout+' -v'), # doctest: +ELLIPSIS
-    Installing 'zc.buildout', 'setuptools'.
+    Installing 'zc.buildout', 'distribute'.
     ...
     Picked: demo = 0.4c1
     ...
@@ -2289,7 +2289,7 @@
     ... ''' % globals())
 
     >>> print system(buildout+' -v'), # doctest: +ELLIPSIS
-    Installing 'zc.buildout', 'setuptools'.
+    Installing 'zc.buildout', 'distribute'.
     ...
     Picked: demo = 0.4c1
     ...
@@ -2311,7 +2311,7 @@
     ... ''' % globals())
 
     >>> print system(buildout+' -v'), # doctest: +ELLIPSIS
-    Installing 'zc.buildout', 'setuptools'.
+    Installing 'zc.buildout', 'distribute'.
     ...
     Picked: demo = 0.3
     ...
@@ -2370,9 +2370,9 @@
 
     """
 
-def dont_pick_setuptools_if_version_is_specified_when_required_by_src_dist():
+def dont_pick_distribute_if_version_is_specified_when_required_by_src_dist():
     """
-When installing a source distribution, we got setuptools without
+When installing a source distribution, we got distribute without
 honoring our version specification.
 
     >>> mkdir('dist')
@@ -2393,14 +2393,14 @@
     ... allow-picked-versions = false
     ...
     ... [versions]
-    ... setuptools = %s
+    ... distribute = %s
     ... foo = 1
     ...
     ... [foo]
     ... recipe = zc.recipe.egg
     ... eggs = foo
     ... ''' % pkg_resources.working_set.find(
-    ...    pkg_resources.Requirement.parse('setuptools')).version)
+    ...    pkg_resources.Requirement.parse('distribute')).version)
 
     >>> print system(buildout),
     Installing foo.
@@ -2699,7 +2699,7 @@
             '-q', 'bdist_egg', '-d', eggs,
             dict(os.environ,
                  PYTHONPATH=pkg_resources.working_set.find(
-                               pkg_resources.Requirement.parse('setuptools')
+                               pkg_resources.Requirement.parse('distribute')
                                ).location,
                  ),
             ) == 0
@@ -2717,10 +2717,10 @@
 
     # now let's make the new releases
     makeNewRelease('zc.buildout', ws, new_releases)
-    makeNewRelease('setuptools', ws, new_releases)
+    makeNewRelease('distribute', ws, new_releases)
 
     os.mkdir(os.path.join(new_releases, 'zc.buildout'))
-    os.mkdir(os.path.join(new_releases, 'setuptools'))
+    os.mkdir(os.path.join(new_releases, 'distribute'))
 
 
 
@@ -2745,7 +2745,7 @@
                 '__buildout_signature__ = recipes-SSSSSSSSSSS'),
                (re.compile('executable = [\S ]+python\S*', re.I),
                 'executable = python'),
-               (re.compile('[-d]  setuptools-\S+[.]egg'), 'setuptools.egg'),
+               (re.compile('[-d]  distribute-\S+[.]egg'), 'distribute.egg'),
                (re.compile('zc.buildout(-\S+)?[.]egg(-link)?'),
                 'zc.buildout.egg'),
                (re.compile('creating \S*setup.cfg'), 'creating setup.cfg'),
@@ -2786,12 +2786,12 @@
                zc.buildout.testing.normalize_egg_py,
                normalize_bang,
                (re.compile('99[.]99'), 'NINETYNINE.NINETYNINE'),
-               (re.compile('(zc.buildout|setuptools)-\d+[.]\d+\S*'
+               (re.compile('(zc.buildout|distribute)-\d+[.]\d+\S*'
                            '-py\d.\d.egg'),
                 '\\1.egg'),
-               (re.compile('(zc.buildout|setuptools)( version)? \d+[.]\d+\S*'),
+               (re.compile('(zc.buildout|distribute)( version)? \d+[.]\d+\S*'),
                 '\\1 V.V'),
-               (re.compile('[-d]  setuptools'), '-  setuptools'),
+               (re.compile('[-d]  distribute'), '-  distribute'),
                ])
             ),
 
@@ -2807,7 +2807,7 @@
                zc.buildout.testing.normalize_egg_py,
                normalize_bang,
                (re.compile('extdemo[.]pyd'), 'extdemo.so'),
-               (re.compile('[-d]  setuptools-\S+[.]egg'), 'setuptools.egg'),
+               (re.compile('[-d]  distribute-\S+[.]egg'), 'distribute.egg'),
                (re.compile(r'\\[\\]?'), '/'),
                ]),
             ),
@@ -2836,16 +2836,16 @@
                zc.buildout.testing.normalize_egg_py,
                (re.compile("buildout: Running \S*setup.py"),
                 'buildout: Running setup.py'),
-               (re.compile('setuptools-\S+-'),
-                'setuptools.egg'),
+               (re.compile('distribute-\S+-'),
+                'distribute.egg'),
                (re.compile('zc.buildout-\S+-'),
                 'zc.buildout.egg'),
                (re.compile('File "\S+one.py"'),
                 'File "one.py"'),
                (re.compile(r'We have a develop egg: (\S+) (\S+)'),
                 r'We have a develop egg: \1 V'),
-               (re.compile('Picked: setuptools = \S+'),
-                'Picked: setuptools = V'),
+               (re.compile('Picked: distribute = \S+'),
+                'Picked: distribute = V'),
                (re.compile(r'\\[\\]?'), '/'),
                (re.compile(
                    '-q develop -mxN -d "/sample-buildout/develop-eggs'),
@@ -2867,7 +2867,7 @@
                zc.buildout.testing.normalize_egg_py,
                (re.compile('__buildout_signature__ = recipes-\S+'),
                 '__buildout_signature__ = recipes-SSSSSSSSSSS'),
-               (re.compile('[-d]  setuptools-\S+[.]egg'), 'setuptools.egg'),
+               (re.compile('[-d]  distribute-\S+[.]egg'), 'distribute.egg'),
                (re.compile('zc.buildout(-\S+)?[.]egg(-link)?'),
                 'zc.buildout.egg'),
                (re.compile('creating \S*setup.cfg'), 'creating setup.cfg'),
@@ -2910,7 +2910,7 @@
                zc.buildout.testing.normalize_endings,
                zc.buildout.testing.normalize_script,
                normalize_bang,
-               (re.compile('Downloading.*setuptools.*egg\n'), ''),
+               (re.compile('Downloading.*distribute.*egg\n'), ''),
                ]),
             ))
 
@@ -1892,7 +1892,7 @@
     """
 
-    This bug arises from the fact that setuptools is overly restrictive
+    This bug arises from the fact that distribute is overly restrictive
     about file urls, requiring that file urls pointing at directories
     must end in a slash.

Modified: zc.buildout/branches/use_distribute/src/zc/buildout/unzip.txt
===================================================================